README file for distributions_ariana package 

This package contains:

license.txt = license file 
setup.cfg = setup file 
setup.py = setup file to import the package
distributions_ariana = folder containing the python scripts 
	Generaldistribution.py = class for general distributions
    Binomialdistribution.py = class for Binomial distribution 
    Gaussiandistribution.py = class for Gaussian distribution
    __init__.py = initialization file 
    